@@ -197,7 +197,6 @@ class ShellStackWidget(QtWidgets.QWidget):
         """
 
         if shell is self.getCurrentShell():
-
             # Update debug info
             if shell and shell._debugState:
                 info = shell._debugState
@@ -313,7 +312,7 @@ class ShellControl(QtWidgets.QToolButton):
 
         # Create timer
         self._elapsedTimesTimer = QtCore.QTimer(self)
-        self._elapsedTimesTimer.setInterval(200)
+        self._elapsedTimesTimer.setInterval(1000)
         self._elapsedTimesTimer.setSingleShot(False)
         self._elapsedTimesTimer.timeout.connect(self.onElapsedTimesTimer)
 
@@ -488,7 +487,6 @@ class DebugStack(QtWidgets.QToolButton):
         self.triggered.connect(self.onTriggered)
 
     def onTriggered(self, action):
-
         # Get shell
         shell = pyzo.shells.getCurrentShell()
         if not shell:
@@ -516,7 +514,6 @@ class DebugStack(QtWidgets.QToolButton):
             index, frames = -1, []
 
         if (not frames) or (debugmode == 0):
-
             # Remove trace
             self.setMenu(None)
             self.setText("")  # (self._baseText)
@@ -582,8 +579,6 @@ class DebugStack(QtWidgets.QToolButton):
             return "Stack frame is <console>."
         elif filename.startswith("<ipython-input-"):
             return "Stack frame is IPython input."
-        elif filename.startswith("<"):
-            return "Stack frame is special name"
         # Go there!
         result = pyzo.editors.loadFile(filename)
         if not result:
@@ -624,7 +619,6 @@ class InterpreterHelper(QtWidgets.QWidget):
         self.detect()
 
     def detect(self):
-
         python_link = '<a href="https://www.python.org/">Python</a>'
         conda_link = '<a href="https://miniconda.pyzo.org">Miniconda</a>'
         self._the_exe = None
